Credits
=======

The Zope software receives contributions from far and wide.  Here's
the Zope Hall of Fame:

- Stephen Purcell allows us to distribute his PyUnit unit testing
  framework with Zope.

- Jeff Bauer is Zope Dude Number One.  Jeff took over PCGI and
  kept pushing it forward through the years.

- Sam Rushing worked with us at Digital Creations to make Medusa
  the publishing platform for ZServer and the concurrency of Zope2.

- A subset of windows guru Mark Hammond's win32 extensions are
  bundled with win32 binary distributions of Zope.

- Martijn Pieters and Brian Hooper contributed the #in reverse
  attribute.

- Phillip Eby contributed the DTML 'let' tag and many
  other useful ideas, including the inspiration for the DTML
  'call', 'with' and 'return'
  tags.

- The DateTime module was based on work from Ted Horst.

- Jordan Baker contributed the 'try' tag, something we've wanted
  for a long, long time.

- Martijn Pieters chipped in with a safe range function.

- Michael Hauser came up with the name "Zope".

- Eric Kidd from Userland contributed to ZPublisher's support for
  XML-RPC.

- Andrew M. Kuchling wrote the initial version of mod_pcgi, making 
  him extremely cool in our book.

- Oleg Broytmann has taken up the standard of mod_pcgi and moving
  it to be a really amazing thing, and ready for prime time.

- Jephte CLAIN made some patches to European ZopeTime.

- Thanks to Gregor Hoffleit for his work in getting Zope into the
  Debian distribution.

- All the other Zopistas far and wide that stuck with us during
  the Bobo/Principia days and politely push us to make the best damn
  app server on this or any other planet.

- Of course the list of credits would be quite incomplete without
  mentioning Guido van Rossum, benevolent dictator of Python and
  long-time friend of Digital Creations.  Zope Power is Python
  Power.

- Special thanks to Richard Stallman and the Free Software
  Foundation for their assistance and feedback on the
  GPL-compatible 2.0 version of the Zope Public License.



